@@ -10,7 +10,7 @@ class Sequence(models.Model):
         primary_key=True,
     )
 
-    last = models.PositiveIntegerField(
+    last = models.PositiveBigIntegerField(
         verbose_name=_("last value"),
     )
 
@@ -19,5 +19,4 @@ class Sequence(models.Model):
         verbose_name_plural = _("sequences")
 
     def __str__(self):
-        return "Sequence(name={}, last={})".format(
-            repr(self.name), repr(self.last))
+        return f"Sequence(name={self.name!r}, last={self.last!r})"
